@@ -27,7 +27,7 @@ use Password::Policy::Exception::PwnedError;
 use LWP::UserAgent;
 use Digest::SHA 'sha1_hex';
 
-our $VERSION = '0.00_02';
+our $VERSION = '0.00_03';
 my $ua = __PACKAGE__ . '/' . $VERSION;
 my $timeout = 5;
 our $base_url = 'https://api.pwnedpasswords.com/range/';
@@ -57,19 +57,18 @@ Password::Policy::Rule::Pwned - Check passwords haven't been pwned
 
 =head1 SYNOPSIS
 
-	use Password::Policy;
-	use Password::Policy::Rule::Pwned;
-	use Try::Tiny;
+    use Password::Policy;
+    use Try::Tiny;
 
-	my $pass = 'password1';
+    my $pass = 'password1';
 
-	my $pp = Password::Policy->new (config => 'policy.yaml');
-	try {
-    	$pp->process({ password => $pass });
-	} catch {
-    	warn "This password '$pass' is pwned - don't use it";
-		# Other actions
-	}
+    my $pp = Password::Policy->new (config => 'policy.yaml');
+    try {
+        $pp->process({ password => $pass });
+    } catch {
+        warn "This password '$pass' is pwned - don't use it";
+        # Other actions
+    }
 
 =head1 DESCRIPTION
 
@@ -79,11 +78,64 @@ range function to ensure that neither the password nor its full hash is
 ever transferred over the wire.
 
 The Password::Policy configuration file should set the "pwned" attribute
-to 1 in any policy where this rule should apply.
+to 1 in any policy where this rule should apply. A trivial example of
+such a policy might be:
+
+    ---
+    default:
+        length: 8
+        algorithm: "Plaintext"
+        pwned: 1
+
+As with all other L<Password::Policy::Rule> types, this will throw an
+exception to indicate an unsafe password. As it relies on a network
+service to operate it will also throw an exception if the service is
+unavailable for whatever reason. The two exceptions are different and
+may be interrogated to determine the difference.
+
+    try {
+        $pp->process({ password => $pass });
+    } catch {
+        if (/has been pwned/) {
+            warn "This password '$pass' is pwned - don't use it";
+        } elsif (/Invalid response/) {
+            warn "Could not check if password is pwned - use at own risk";
+        } else {
+            warn "Password not pwned but still bad: $_";
+        }
+        # Other actions
+    }
+
+=head1 METHODS
+
+=head2 check
+
+    $rule->check ($clearpw);
+
+This method is not expected to be called directly but rather via
+C<Password::Policy-E<gt>process>. It takes one argument which is the
+password to be checked. If the password is a utf-8 string it must be
+encoded first.
+
+The method will throw a L<Password::Policy::Exception::Pwned> exception
+if the password is pwned. If the API server is unavailable it will warn
+and then throw a L<Password::Policy::Exception::PwnedError> exception. It
+will return true if the password is verifiably not pwned.
 
 =head1 STATUS
 
-B<This is alpha quality software.> It is not yet production ready.
+B<This is beta quality software.> It has been tested and may be used at
+your own risk. The details of the implementation and interface may yet
+be changed in future releases.
+
+=head1 DATA SOURCE
+
+Note that this code is merely a user-friendly API client. It relies
+entirely upon the data held at api.pwnedpasswords.com and which is made
+available free of charge to end users such as your good self. If this
+data is useful to you then please consider making a
+L<donation|https://haveibeenpwned.com/Donate> to help fund this service
+and allow Troy's good work to continue.
 
 =head1 SEE ALSO
 
@@ -100,7 +152,7 @@ This module is written and maintained by Pete Houston of Openstrike
 <cpan@openstrike.co.uk>
 
 =head1 COPYRIGHT INFORMATION
-    
+
 Copyright 2018 by Pete Houston. All Rights Reserved.
 
 Permission to use, copy, and  distribute  is  hereby granted,
